@@ -10,7 +10,7 @@ class ArticleAdmin(DefaultAdminMixin):
         TitleAdminFieldsetMixin,
     ]
     fieldset_fields = {
-        "default": ["clicks", "...!"]
+        "default": ["...!"]
     }
 
 
